@@ -11,7 +11,7 @@ class TestFactory(unittest.TestCase):
     """
     Test that the get_classname method works as expected.
     """
-    self.assertEqual(RegionEstimatorFactory.get_classname('diffusion'), 'DiffusionEstimator')
+    self.assertEqual(RegionEstimatorFactory.get_classname('concentric-regions'), 'ConcentricRegionsEstimator')
     self.assertEqual(RegionEstimatorFactory.get_classname('distance-simple'), 'DistanceSimpleEstimator')
     with self.assertRaises(ValueError):
       RegionEstimatorFactory.get_classname('___')
